/*
* Fetchify for Shopware
*
* @author		Fetchify (formerly Crafty Clicks)
* @link			https://fetchify.com
* @copyright	Copyright (c) 2020, Fetchify
* @version		1.2.0
*/

if (typeof window.cc_c2a_functions == 'undefined') {
	window.cc_c2a_functions = {
		autocomplete: {},
		email: {},
		phone: {}
	};
	window.cc_c2a_functions.wait = function() {
		if (window.cc_c2a_config.autocomplete.enabled == "enabled" ||
			window.cc_c2a_config.email.enabled == "enabled" ||
			window.cc_c2a_config.phone.enabled == "enabled")
		{
			if (typeof jQuery != 'undefined' && typeof clickToAddress != 'undefined') {
				jQuery(document).ready(function(){
					setInterval(function(){
						window.cc_c2a_functions.autocomplete.add_autocomplete();
						window.cc_c2a_functions.email.add_email();
						window.cc_c2a_functions.phone.add_phone();
					}, 200);
				});
			}
			else {
				setTimeout(window.cc_c2a_functions.wait, 30);
			}
		}
	}
}
window.cc_c2a = null;

window.cc_c2a_functions.autocomplete.add_autocomplete = function() {
	if (window.cc_c2a_config.autocomplete.enabled != "enabled") {
		return;
	}

	var cc_forms = jQuery(document).find('input[id*="street"]');
	if(cc_forms.length && cc_forms.attr('cc_applied') !== '1') {
		cc_forms.attr('cc_applied', '1');
		var config = {
			tag:			window.cc_c2a_config.autocomplete.tag,
			accessToken:	window.cc_c2a_config.general.access_token,
			gfxMode:		'1',
			domMode:		'object',
			style:{
				ambient:	window.cc_c2a_config.autocomplete.ambient,
				accent:		window.cc_c2a_config.autocomplete.accent
			},
			showLogo:		(window.cc_c2a_config.autocomplete.show_logo === "0") ? false : true,
			texts: {
				default_placeholder:	window.cc_c2a_config.autocomplete.default_placeholder,
				country_placeholder:	window.cc_c2a_config.autocomplete.country_placeholder,
				country_button:		window.cc_c2a_config.autocomplete.country_button,
				generic_error:		window.cc_c2a_config.autocomplete.generic_error,
				no_results:	window.cc_c2a_config.autocomplete.no_results
			},
			countryLanguage:		window.cc_c2a_config.autocomplete.language,
			enabledCountries:		window.cc_c2a_functions.autocomplete.countries_by_shopware(),
			onResultSelected: function(c2a, elements, address){
				var form = jQuery(elements.search).closest('div').parent();
				window.cc_c2a_functions.autocomplete.show_fields(form);
				//use magic against the inconsistent country list
				jQuery.each(window.cc_c2a_config.general.countries_from_backend, function(index, value){
					//logic: compare iso3 of returned address and shopware backend iso3
					//that way we avoid doing anything with the unreliable values of those fields
					if(value.iso3.toUpperCase() == address.country.iso_3166_1_alpha_3){
						jQuery(elements.country).find('option:contains('+value.countryname+')').prop('selected', true);
					}
				});
				jQuery(elements.country).trigger('change');
			},
			onError: function(c2a, elements, address){
				var form = jQuery(elements.search).closest('div').parent();
				window.cc_c2a_functions.autocomplete.show_fields(form);
			}
		};
		if (window.cc_c2a === null) {
			window.cc_c2a = new clickToAddress(config);
		}

		//this one is needed
		jQuery('#cc_c2a').css('z-index', '1000000');
		jQuery.each(cc_forms, function(index, elem){
			window.cc_c2a_functions.autocomplete.add_autocomplete_form(elem, config);
		});
	}
}

window.cc_c2a_functions.autocomplete.add_autocomplete_form = function(currentStreetInput, config) {
	//get the elements
	var formContainer = jQuery(currentStreetInput).closest('div').parent();
	var postfix = currentStreetInput.id == "street" ? "" : "2";

	var dom = {
		line_1:		jQuery('#street'+postfix),
		town:		jQuery('#city'+postfix),
		postcode:	jQuery('#zipcode'+postfix),
		country:	jQuery('#country'+postfix)
	};
	//special clause for shipping form (id inconsistency)
	if (postfix == "2") {
		dom.country = jQuery('#country_shipping');
		dom.company = jQuery('#company'+postfix);
	}
	//check the destination of the address search
	if (window.cc_c2a_config.autocomplete.search_place == "true") {
		dom.search = dom.line_1;
	}
	else {
		var searchField = jQuery('<div><input type="text" id="search_field'+postfix+'" class="register--field address--field" placeholder="'+config.texts.default_placeholder+'"></input></div>');
		searchField.insertBefore(jQuery(currentStreetInput).closest('div'));
		dom.search = jQuery('#search_field'+postfix);
	}

	//if hide addresses, let the tagging game begin
	if(window.cc_c2a_config.autocomplete.hide_fields == "1" && dom.line_1.val() === '' && window.cc_c2a_config.autocomplete.search_place != "true"){
		jQuery.each(dom, function(index, value){
			if (index == "search") return;
			value.closest('div').addClass('cc-hidden');
		});
		//hide the fields
		formContainer.find('.cc-hidden').css('display', 'none');

		//add guide-labels
		var guideLabelStyle = {
			'float' : 'right',
			'cursor' : 'pointer',
			'font-size' : '0.8em'
		};

		var manualLabel = jQuery('<label class="chklabel cc_show_label">'+window.cc_c2a_config.autocomplete.show_label+'</label>');
		manualLabel
			.css(guideLabelStyle)
			.on('hover', function(){jQuery(this).css('text-decoration' , 'underline');})
			.on('click', function(){
				jQuery(this).closest('div').parent().find('.cc-hidden').show(200);
				jQuery(this).hide(200);
			});

		var guideLabels = jQuery('<div></div>').append(manualLabel);
		guideLabels.insertBefore(dom.search.closest('div'));

	}
	var dom_elem = {};
	jQuery.each(dom, function(index, elem){
		if(elem.length){
			dom_elem[index] = elem[0];
		}
	});
	window.cc_c2a.addAddressComplete(dom_elem);
}

window.cc_c2a_functions.autocomplete.show_fields = function(form) {
	form.find('.cc-hidden').show(200);
	form.find('.cc_show_label').hide(200).off();
}

window.cc_c2a_functions.autocomplete.countries_by_shopware = function() {
	var frontend_country_names = [],
		countries = [];
	jQuery.each(jQuery('#country option'), function(){
		//we need some text juggling (remove line breaks, lowercasing)
		var temp = jQuery(this).text();
		temp = temp.replace(/(\r\n|\n|\r)/gm,"").trim().toLowerCase();
		frontend_country_names.push(temp);
	});

	jQuery.each(window.cc_c2a_config.general.countries_from_backend, function(index, value){
		if(frontend_country_names.indexOf(value.countryname.toLowerCase()) > -1)
			countries.push(value.iso3.toLowerCase());
	});
	return countries;
}

window.cc_c2a_functions.email.add_email = function() {
	if (window.cc_c2a_config.email.enabled != "enabled") {
		return;
	}

	if ((window.cc_c2a_config.autocomplete.enabled != "enabled" || jQuery('input[name="email\[email\]"]').length) && window.cc_c2a === null) {
		window.cc_c2a = new clickToAddress({
			accessToken: window.cc_c2a_config.general.access_token
		});
	}

	var cc_email_fields = ['#register_personal_email', 'input[name="email\[email\]"]'];

	for (var i = 0; i < cc_email_fields.length; i++) {
		if (window.cc_c2a !== null && jQuery(cc_email_fields[i]).length && jQuery(cc_email_fields[i]).attr('cc-applied') != "1") {
			window.cc_c2a.addEmailVerify({
				email: cc_email_fields[i]
			});
			jQuery(cc_email_fields[i]).attr('cc-applied', "1");
			// jQuery('#cc_validate_box').css({zIndex: 7001}); // For change address on checkout
		}
	}
}

window.cc_c2a_functions.phone.add_phone = function() {
	if (window.cc_c2a_config.phone.enabled != "enabled") {
		return;
	}

	if (window.cc_c2a_config.autocomplete.enabled != "enabled" && window.cc_c2a === null) {
		window.cc_c2a = new clickToAddress({
			accessToken: window.cc_c2a_config.general.access_token
		});
	}

	var cc_phone_fields = ['#phone'];

	for (var i = 0; i < cc_phone_fields.length; i++) {
		if (window.cc_c2a !== null && jQuery(cc_phone_fields[i]).length && jQuery(cc_phone_fields[i]).attr('cc-applied') != "1") {
			window.cc_c2a.addPhoneVerify({
				phone: cc_phone_fields[i],
				country: function(){
					var selectedCountry = jQuery('#country').val();
					var selectedCountryText = null;
					var selectedCountryCode = window.cc_c2a_config.phone.default_country;
					if (selectedCountry !== null) {
						jQuery.each(jQuery('#country option'), function(index, elem) {
							if (selectedCountry == elem.value) {
								selectedCountryText = jQuery(elem).text();
								selectedCountryText = selectedCountryText.replace(/(\r\n|\n|\r)/gm,"").trim().toLowerCase();
							}
						});
					}
					if (selectedCountryText !== null) {
						jQuery.each(window.cc_c2a_config.general.countries_from_backend, function(index, value){
							if (value.countryname.toLowerCase() == selectedCountryText) {
								selectedCountryCode = value.iso;
							}
						});
					}
					return selectedCountryCode;
				}
			});
			jQuery(cc_phone_fields[i]).attr('cc-applied', "1");
			jQuery('#cc_validate_box').css({zIndex: 7001}); // For change address on checkout
		}
	}
}

window.cc_c2a_functions.wait();
